@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -33,9 +33,6 @@ public:
 
     void configurationChanged();
 
-Q_SIGNALS:
-    void needUpdateConfigDialogBox();
-
 public Q_SLOTS:
     void configure(WId windowId) override;
 
