@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -11,14 +11,15 @@
 #include "noteshared_export.h"
 class KJob;
 
-namespace NoteShared {
+namespace NoteShared
+{
 class CreateNewNoteJobPrivate;
 class NOTESHARED_EXPORT CreateNewNoteJob : public QObject
 {
     Q_OBJECT
 public:
     explicit CreateNewNoteJob(QObject *parent = nullptr, QWidget *widget = nullptr);
-    ~CreateNewNoteJob();
+    ~CreateNewNoteJob() override;
 
     void setNote(const QString &name, const QString &text);
 
@@ -35,6 +36,7 @@ private Q_SLOTS:
     void slotFetchCollection(KJob *job);
     void slotCollectionModifyFinished(KJob *job);
     void slotSelectNewCollection();
+
 private:
     void createFetchCollectionJob(bool useSettings);
     CreateNewNoteJobPrivate *const d;
