@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -10,7 +10,8 @@
 #include <QObject>
 
 class KJob;
-namespace NoteShared {
+namespace NoteShared
+{
 class NOTESHARED_EXPORT LocalResourceCreator : public QObject
 {
     Q_OBJECT
