@@ -1,17 +1,17 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "knoteselectednotesdialog.h"
 #include "notes/knote.h"
 
-#include <KLocalizedString>
 #include <KConfigGroup>
+#include <KLocalizedString>
 
-#include <QListWidget>
 #include <KSharedConfig>
 #include <QDialogButtonBox>
+#include <QListWidget>
 #include <QPushButton>
 #include <QVBoxLayout>
 
@@ -19,7 +19,7 @@ KNoteSelectedNotesDialog::KNoteSelectedNotesDialog(QWidget *parent)
     : QDialog(parent)
 {
     setWindowTitle(i18nc("@title:window", "Select notes"));
-    auto *mainLayout = new QVBoxLayout(this);
+    auto mainLayout = new QVBoxLayout(this);
     mListNotes = new QListWidget(this);
     mListNotes->setSelectionMode(QAbstractItemView::ExtendedSelection);
 
@@ -56,7 +56,7 @@ void KNoteSelectedNotesDialog::setNotes(const QHash<Akonadi::Item::Id, KNote *>
     QHashIterator<Akonadi::Item::Id, KNote *> i(notes);
     while (i.hasNext()) {
         i.next();
-        auto *item = new QListWidgetItem(mListNotes);
+        auto item = new QListWidgetItem(mListNotes);
         item->setText(i.value()->name());
         item->setToolTip(i.value()->text());
         item->setData(AkonadiId, i.key());
