@@ -1,13 +1,13 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 #ifndef KNOTESELECTEDNOTESDIALOG_H
 #define KNOTESELECTEDNOTESDIALOG_H
 
-#include <QDialog>
 #include <AkonadiCore/Item>
+#include <QDialog>
 class QListWidget;
 class KNote;
 class QPushButton;
@@ -16,7 +16,7 @@ class KNoteSelectedNotesDialog : public QDialog
     Q_OBJECT
 public:
     explicit KNoteSelectedNotesDialog(QWidget *parent = nullptr);
-    ~KNoteSelectedNotesDialog();
+    ~KNoteSelectedNotesDialog() override;
 
     void setNotes(const QHash<Akonadi::Item::Id, KNote *> &notes);
 
@@ -26,9 +26,7 @@ private Q_SLOTS:
     void slotSelectionChanged();
 
 private:
-    enum listViewData {
-        AkonadiId = Qt::UserRole + 1
-    };
+    enum listViewData { AkonadiId = Qt::UserRole + 1 };
 
     void writeConfig();
     void readConfig();
