@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,8 +7,8 @@
 #ifndef KNOTEPRINTSELECTTHEMEDIALOG_H
 #define KNOTEPRINTSELECTTHEMEDIALOG_H
 
-#include <QDialog>
 #include "knotes_export.h"
+#include <QDialog>
 
 class KNotePrintSelectThemeComboBox;
 class KNOTES_EXPORT KNotePrintSelectThemeDialog : public QDialog
@@ -16,7 +16,7 @@ class KNOTES_EXPORT KNotePrintSelectThemeDialog : public QDialog
     Q_OBJECT
 public:
     explicit KNotePrintSelectThemeDialog(QWidget *parent = nullptr);
-    ~KNotePrintSelectThemeDialog();
+    ~KNotePrintSelectThemeDialog() override;
 
     Q_REQUIRED_RESULT QString selectedTheme() const;
 
